package de.intevation.artifactdatabase;

import java.io.IOException;
import java.io.OutputStream;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

/**
 * Trivial implementation of an artifact. Useful to subclass.
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class DefaultArtifact
implements   Artifact
{
    private static Logger logger = Logger.getLogger(DefaultArtifact.class);

    /**
     * The identifier of the artifact.
     */
    protected String identifier;

    /**
     * Default constructor.
     */
    public DefaultArtifact() {
    }


    public void setIdentifier(String identifier) {
        if (logger.isDebugEnabled()) {
            logger.debug("Change identifier: "
                + this.identifier + " -> " + identifier);
        }
        this.identifier = identifier;
    }

    public String identifier() {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.identifier: " + identifier);
        }
        return this.identifier;
    }

    public String hash() {
        String hash = String.valueOf(hashCode());
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.hashCode: "
                + identifier + " (" + hash + ")");
        }
        return hash;
    }

    public Document describe(Document data, CallContext context) {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.describe: " + identifier);
        }
        return XMLUtils.newDocument();
    }

    public Document advance(Document target, CallContext context) {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.advance: " + identifier);
        }
        return XMLUtils.newDocument();
    }

    public Document feed(Document target, CallContext context) {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.feed: " + identifier);
        }
        return XMLUtils.newDocument();
    }

    public void out(
        Document     format,
        OutputStream out,
        CallContext  context
    )
    throws IOException
    {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.out: " + identifier);
        }
    }

    public void setup(String identifier, ArtifactFactory factory,
                      Object context, Document data) {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.setup: " + identifier);
        }
        this.identifier = identifier;
    }

    public void endOfLife(Object context) {
        if (logger.isDebugEnabled()) {
            logger.debug("DefaultArtifact.endOfLife: " + identifier);
        }
    }

    public void cleanup(Object context) {
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
